plotc: Plot the computed clusters igraph.

Description Usage Arguments Value Examples

View source: R/ProKlust.R

Description

networkD3 library is used to plot the graph and a HTML copy file named network.html is created.

Usage

1
plotc(igraph, plotFontSize = 10, plotLinkDistance = 60, nodeAttraction = -10)

Arguments

igraph

Obligatory igraph object.

plotFontSize

Optional numeric font size in pixels for the node text labels.

plotLinkDistance

Optional numeric or character string. Either numberic fixed distance between the links in pixels (actually arbitrary relative to the diagram's size). Or a JavaScript function, possibly to weight by Value. For example: linkDistance = JS("function(d)return d.value * 10").

nodeAttraction

Optional numeric value indicating either the strength of the node repulsion (negative value) or attraction (positive value)

Value

The actual plot of the network (an igraph which was transformed into graphical plot by networkD3).

Examples

1
2
3
4
files <- c("ANIb_percentage_identity.tab", "ANIb_alignment_coverage.tab")
thresholds <- c(0.95, 0.70)
results <- prokluster(filenames = files, cutoffs = thresholds, nodesDictionary = "dictionary.tab")
plottedD3 <- plotc(results$graph)

camilagazolla/ProKlust documentation built on May 22, 2021, 11:10 p.m.