Description Usage Arguments Value Examples
networkD3 library is used to plot the graph and a HTML copy file named network.html is created.
1 | plotc(igraph, plotFontSize = 10, plotLinkDistance = 60, nodeAttraction = -10)
|
igraph |
Obligatory igraph object. |
plotFontSize |
Optional numeric font size in pixels for the node text labels. |
plotLinkDistance |
Optional numeric or character string. Either numberic fixed distance between the links in pixels (actually arbitrary relative to the diagram's size). Or a JavaScript function, possibly to weight by Value. For example: linkDistance = JS("function(d)return d.value * 10"). |
nodeAttraction |
Optional numeric value indicating either the strength of the node repulsion (negative value) or attraction (positive value) |
The actual plot of the network (an igraph which was transformed into graphical plot by networkD3).
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.